@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1993-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1993-2000 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: edit.cc,v 1.18 1999/11/06 16:57:54 lav Exp $ */
+/* $Id: edit.cc,v 1.26 2001/06/08 10:31:00 lav Exp $ */
 
 /* edit.c : main editor loop */
 
@@ -40,6 +40,7 @@
 #include "screen.h"
 #include "options.h"
 #include "about.h"
+#include "search.h"
 #ifdef WITH_MOUSE
 # include "mouse.h"
 #endif
@@ -48,8 +49,8 @@
 
 // #include <term.h>
 
-#ifdef __MSDOS__
-#define	 fcntl(x,y,z)	(0)
+#ifdef DISABLE_FILE_LOCKS
+# define fcntl(x,y,z)	(0)
 #endif
 
 #include <xalloca.h>
@@ -128,21 +129,13 @@ void ProcessDragMark()
 void    Edit()
 {
    int      key;
-   num      std;
    int      action;
    ActionProc proc;
    num	 old_num_of_lines=-1;
 
    while(1)
    {
-      std=stdcol;
-      if(!hex)
-      {
-         while(GetCol()>std)
-           MoveLeft();
-         while(GetCol()<std && !Eol())
-           MoveRight();
-      }
+      SeekStdCol();
       if(hex)
          flag|=REDISPLAY_LINE;
 
@@ -155,6 +148,7 @@ void    Edit()
       if(DragMark)
 	 ProcessDragMark();
 
+      ClearMessage();
       SyncTextWin();
       StatusLine();
       SetCursor();
@@ -311,7 +305,7 @@ void    Quit()
 }
 int     AskToSave()
 {
-   if(modified)
+   if(modified && !View)
    {
       static struct menu Menu[]={
       {"   &Yes   "},{"   &No   "},{" &Cancel "},
@@ -441,7 +435,7 @@ void    Initialize()
    l.l_type=F_RDLCK;
    l.l_whence=SEEK_SET;
    l.l_start=l.l_len=0;
-   Message("Loading history...");
+   MessageSync("Loading history...");
    f=fopen(HstName,"rb");
    if(f && fcntl(fileno(f),F_SETLKW,&l)!=-1)
    {
@@ -453,6 +447,8 @@ void    Initialize()
 
    EditorReadKeymap();
    RebuildKeyTree();
+
+   LoadMainMenu();
 }
 void    Terminate()
 {
@@ -467,7 +463,7 @@ void    Terminate()
    {
       if(SaveHst)
       {
-         Message("Saving history...");
+         MessageSync("Saving history...");
          int fd=open(HstName,O_RDWR|O_CREAT,0644);
          struct flock l;
 	 l.l_type=F_RDLCK;
@@ -707,8 +703,6 @@ int     main(int argc,char **argv)
       for(; optind<argc; optind++)
          LoadHistory+=argv[optind];
       sprintf(newname,"%.255s",argv[argc-1]);
-      if(ChooseFileName(newname)<0)
-	 newname[0]=0;
    }
    if(newname[0] && file_check(newname)==ERR)
    {
