@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1993-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1993-2000 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,16 +16,23 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: highli.cc,v 1.9 1999/07/11 10:49:58 lav Exp $ */
+/* $Id: highli.cc,v 1.15 2001/04/13 09:08:59 lav Exp $ */
 
 #include <config.h>
 
-#include "highli.h"
-#include "edit.h"
-#include "screen.h"
 #include <fnmatch.h>
 #include <string.h>
 #include <stdlib.h>
+#include "highli.h"
+#include "edit.h"
+#include "screen.h"
+#include "search.h"
+#include "xalloca.h"
+
+#ifdef HAVE_SYS_TIMES_H
+#include <sys/times.h>
+#endif
+#include <limits.h>
 
 int hl_option=1;
 int hl_active=0;
@@ -49,13 +56,14 @@ syntax_hl::syntax_hl(int color,int mask)
    this->color=color;
    this->mask=mask;
    memset(&rexp_c,0,sizeof(rexp_c));
+   memset(&regs,0,sizeof(regs));
 }
 
 syntax_hl::~syntax_hl()
 {
    if(rexp)
    {
-      delete rexp;
+      free(rexp);
       regfree(&rexp_c);
    }
    for(syntax_hl **scan=&chain; ; scan=&(**scan).next)
@@ -74,24 +82,36 @@ void syntax_hl::free_chain()
       delete chain;
 }
 
-const char *syntax_hl::set_rexp(const char *nr)
+const char *syntax_hl::set_rexp(const char *nr,bool ignore_case)
 {
    if(rexp)
    {
-      delete rexp;
+      free(rexp);
       regfree(&rexp_c);
       memset(&rexp_c,0,sizeof(rexp_c));
       rexp=0;
+      if(regs.start)
+	 free(regs.start);
+      if(regs.end)
+	 free(regs.end);
+      memset(&regs,0,sizeof(regs));
+   }
+   rexp=strdup(nr);
+   if(rexp==0)
+      return 0;
+   if(ignore_case)
+   {
+      map_to_lower_init();
+      rexp_c.translate=(RE_TRANSLATE_TYPE)malloc(256);
+      memcpy(rexp_c.translate,map_to_lower,256);
    }
    re_syntax_options=RE_NO_BK_VBAR|RE_NO_BK_PARENS|RE_INTERVALS|
 		     RE_CHAR_CLASSES|RE_CONTEXT_INDEP_ANCHORS;
-   const char *err=re_compile_pattern(nr,strlen(nr),&rexp_c);
+   const char *err=re_compile_pattern(rexp,strlen(rexp),&rexp_c);
    if(err)
       return err;
    rexp_c.fastmap=(char*)malloc(256);
    re_compile_fastmap(&rexp_c);
-   rexp=new char[strlen(nr)+1];
-   strcpy(rexp,nr);
    return 0;
 }
 
@@ -246,6 +266,12 @@ void InitHighlight()
 	    fskip(f);
 	    continue;
 	 }
+	 bool ignore_case=false;
+	 int c=fgetc(f);
+	 if(c=='i')
+	    ignore_case=true;
+	 else
+	    ungetc(c,f);
 	 res=fscanf(f,"%d,%i=",&color,&mask);
 	 if(res!=2)
 	 {
@@ -303,7 +329,7 @@ void InitHighlight()
 	 }
 	 c_string_interpret(accum);
 	 syntax_hl *hl=new syntax_hl(color,mask);
-	 const char *err=hl->set_rexp(accum);
+	 const char *err=hl->set_rexp(accum,ignore_case);
 	 if(err)
 	 {
 	    ErrMsg(err);
@@ -395,6 +421,12 @@ void syntax_hl::attrib_line(const char *buf1,int len1,
    element *el;
    element **elpp;
 
+#ifdef HAVE_TIMES
+   struct tms tms;
+   times(&tms);
+   clock_t clock=tms.tms_utime;
+#endif
+
    for(syntax_hl *scan=chain; scan; scan=scan->next)
    {
       int pos=0;
@@ -403,7 +435,9 @@ void syntax_hl::attrib_line(const char *buf1,int len1,
       {
 	 pos=re_search_2(&scan->rexp_c,buf1,len1,buf2,len2,
 			 pos,ll-pos,&scan->regs,ll);
-	 if(pos==-1)
+	 if(pos==-1) // not found
+	    break;
+	 if(pos==-2) // error ?
 	    break;
 	 unsigned r;
 	 unsigned m;
@@ -425,6 +459,13 @@ void syntax_hl::attrib_line(const char *buf1,int len1,
 	    *elpp=el;
 	 }
 	 pos++;
+
+#ifdef HAVE_TIMES
+	 times(&tms);
+	 clock_t clock1=tms.tms_utime;
+	 if(clock1-clock>CLK_TCK/5)
+	    break;
+#endif
       }
    }
    for(el=els; el; el=el->next)
