@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1993-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1993-2000 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,14 +52,14 @@ ActionCodeRec  DefaultActionCodeTable[]=
    {TEXT_BEGIN,"$kHOM"},
    {TEXT_BEGIN,"\033|$kbeg"},
    {TEXT_BEGIN,"\033|$khome"},
+   {TEXT_BEGIN,"\007|B"},
    {TEXT_BEGIN,"\007|^B"},
    {TEXT_BEGIN,"\007|b"},
-   {TEXT_BEGIN,"\007|B"},
    {TEXT_END,"$kEND"},
    {TEXT_END,"\033|$kend"},
+   {TEXT_END,"\007|E"},
    {TEXT_END,"\007|^E"},
    {TEXT_END,"\007|e"},
-   {TEXT_END,"\007|E"},
    {NEXT_PAGE,"$knp"},
    {NEXT_PAGE,"$kc3"},
    {NEXT_PAGE,"$knxt"},
@@ -72,37 +72,37 @@ ActionCodeRec  DefaultActionCodeTable[]=
    {PAGE_TOP,"$kPRV"},
    {PAGE_BOTTOM,"\033|$knp"},
    {PAGE_BOTTOM,"$kNXT"},
+   {TO_LINE_NUMBER,"\007|G"},
    {TO_LINE_NUMBER,"\007|\007"},
    {TO_LINE_NUMBER,"\007|g"},
-   {TO_LINE_NUMBER,"\007|G"},
    {TO_LINE_NUMBER,"\007|l"},
    {TO_LINE_NUMBER,"\007|L"},
    {TO_LINE_NUMBER,"$kf8"},
    {TO_LINE_NUMBER,"\033|8"},
-   {TO_OFFSET,"\007|\017"},
    {TO_OFFSET,"\007|O"},
+   {TO_OFFSET,"\007|\017"},
    {TO_OFFSET,"\007|o"},
+   {TO_PREVIOUS_LOC,"\007|P"},
    {TO_PREVIOUS_LOC,"\007|\020"},
    {TO_PREVIOUS_LOC,"\007|p"},
-   {TO_PREVIOUS_LOC,"\007|P"},
    {LINE_UP,"$kcuu1"},
    {LINE_DOWN,"$kcud1"},
 
 // Movement with block marking (new xterm codes)
-   {MARK_CHAR_LEFT,"\eO2D"},
-   {MARK_CHAR_RIGHT,"\eO2C"},
-   {MARK_WORD_LEFT,"\eO6D"},
-   {MARK_WORD_RIGHT,"\eO6C"},
-   {MARK_LINE_BEGIN,"\eO2H"},
-   {MARK_LINE_END,"\eO2F"},
-   {MARK_TEXT_BEGIN,"\eO6H"},
-   {MARK_TEXT_END,"\eO6F"},
-   {MARK_NEXT_PAGE,"\e[6;2~"},
-   {MARK_PREV_PAGE,"\e[5;2~"},
-   {MARK_PAGE_TOP,"\e[5;6~"},
-   {MARK_PAGE_BOTTOM,"\e[6;6~"},
-   {MARK_LINE_UP,"\eO2A"},
-   {MARK_LINE_DOWN,"\eO2B"},
+   {MARK_CHAR_LEFT,"\033O2D"},
+   {MARK_CHAR_RIGHT,"\033O2C"},
+   {MARK_WORD_LEFT,"\033O6D"},
+   {MARK_WORD_RIGHT,"\033O6C"},
+   {MARK_LINE_BEGIN,"\033O2H"},
+   {MARK_LINE_END,"\033O2F"},
+   {MARK_TEXT_BEGIN,"\033O6H"},
+   {MARK_TEXT_END,"\033O6F"},
+   {MARK_NEXT_PAGE,"\033[6;2~"},
+   {MARK_PREV_PAGE,"\033[5;2~"},
+   {MARK_PAGE_TOP,"\033[5;6~"},
+   {MARK_PAGE_BOTTOM,"\033[6;6~"},
+   {MARK_LINE_UP,"\033O2A"},
+   {MARK_LINE_DOWN,"\033O2B"},
 
 // Delete actions
    {BACKSPACE_CHAR,"^H"},
@@ -144,24 +144,47 @@ ActionCodeRec  DefaultActionCodeTable[]=
 
 // Block ops
    {COPY_BLOCK,"$kf11"},
+   {COPY_BLOCK,"${kf4}C"},
+   {COPY_BLOCK,"${kf4}c"},
    {MOVE_BLOCK,"$kf12"},
+   {MOVE_BLOCK,"${kf4}M"},
+   {MOVE_BLOCK,"${kf4}m"},
+   {DELETE_BLOCK,"${kf4}D"},
+   {DELETE_BLOCK,"${kf4}d"},
    {DELETE_BLOCK,"$1kf12"},
-   {DELETE_BLOCK,"\e$kf12"},
+   {DELETE_BLOCK,"\033|$kf12"},
+   {DELETE_BLOCK,"\033[3;2~"},
    {SET_BLOCK_END,"$kf6"},
    {SET_BLOCK_END,"\033|6"},
+   {SET_BLOCK_END,"${kf4}E"},
+   {SET_BLOCK_END,"${kf4}e"},
    {SET_BLOCK_BEGIN,"$kf5"},
    {SET_BLOCK_BEGIN,"\033|5"},
-//   {READ_BLOCK,"read-block"},
-//   {WRITE_BLOCK,"write-block"},
+   {SET_BLOCK_BEGIN,"${kf4}B"},
+   {SET_BLOCK_BEGIN,"${kf4}b"},
+   {READ_BLOCK,"${kf4}R"},
+   {READ_BLOCK,"${kf4}r"},
+   {WRITE_BLOCK,"${kf4}W"},
+   {WRITE_BLOCK,"${kf4}w"},
    {PIPE_BLOCK,"\033|\\|"},
-//   {INDENT_BLOCK,"indent-block"},
-//   {UNINDENT_BLOCK,"unindent-block"},
+   {PIPE_BLOCK,"${kf4}\\|"},
+   {INDENT_BLOCK,"${kf4}I"},
+   {INDENT_BLOCK,"${kf4}i"},
+   {UNINDENT_BLOCK,"${kf4}U"},
+   {UNINDENT_BLOCK,"${kf4}u"},
+   {INSERT_PREFIX,"${kf4}>"},
    {INSERT_PREFIX,"\033|>"},
-//   {TO_UPPER,"convert-to-upper"},
-//   {TO_LOWER,"convert-to-lower"},
-//   {EXCHANGE_CASE,"exchange-cases"},
-//   {BLOCK_HIDE,"hide-block"},
-//   {BLOCK_TYPE,"change-block-type"},
+   {INSERT_PREFIX,"\033|."},
+   {TO_UPPER,"${kf4}P"},
+   {TO_UPPER,"${kf4}p"},
+   {TO_LOWER,"${kf4}L"},
+   {TO_LOWER,"${kf4}l"},
+   {EXCHANGE_CASE,"${kf4}X"},
+   {EXCHANGE_CASE,"${kf4}x"},
+   {BLOCK_HIDE,"${kf4}H"},
+   {BLOCK_HIDE,"${kf4}h"},
+   {BLOCK_TYPE,"${kf4}T"},
+   {BLOCK_TYPE,"${kf4}t"},
    {BLOCK_FUNC_BAR,"$kf4"},
    {BLOCK_FUNC_BAR,"\033|4"},
    {MARK_LINE,"\033|$kf5"},
@@ -169,7 +192,15 @@ ActionCodeRec  DefaultActionCodeTable[]=
    {MARK_TO_EOL,"\033|$kf6"},
    {MARK_TO_EOL,"$1kf6"},
    {YANK_BLOCK,"$1kf11"},
-   {YANK_BLOCK,"\e$kf11"},
+   {YANK_BLOCK,"\033|$kf11"},
+   {YANK_BLOCK,"${kf4}Y"},
+   {YANK_BLOCK,"${kf4}y"},
+   {YANK_BLOCK,"\033[2;2~"},
+   {REMEMBER_BLOCK,"$kIC"},
+   {START_DRAG_MARK,"${kf4}V"},
+   {START_DRAG_MARK,"${kf4}v"},
+   {MARK_ALL,"${kf4}A"},
+   {MARK_ALL,"${kf4}a"},
 
 // Search
    {SEARCH_FORWARD,"$kf7"},
@@ -199,7 +230,7 @@ ActionCodeRec  DefaultActionCodeTable[]=
 //   {CALCULATOR,editcalc,"calculator"},
 //   {DRAW_FRAMES,DrawFrames,"draw-frames"},
 //   {TABS_EXPAND,ExpandAllTabs,"expand-tabs"},
-//   {TEXT_OPTIMIZE,Optimize,"optimize-text"},
+//   {TEXT_OPTIMIZE,UserOptimizeText,"optimize-text"},
    {CHOOSE_CHAR,"\005"},
 //   {UNIX_DOS_TRANSFORM,DOS_UNIX,"change-text-type"},
 
@@ -264,6 +295,10 @@ ActionCodeRec  DefaultActionCodeTable[]=
    {SWITCH_GRAPH_MODE,"^A|G"},
    {SWITCH_GRAPH_MODE,"^A|g"},
 
+   {SET_BOOKMARK,"\033|m"},
+   {SET_BOOKMARK,"\033|M"},
+   {GO_BOOKMARK,"\033|'"},
+
 #ifdef __MSDOS__
    {PAGE_TOP,"\200\204"},
    {PAGE_BOTTOM,"\200v"},
