@@ -16,13 +16,23 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/* $Id: mouse.h,v 1.3 1998/10/14 17:29:12 lav Exp $ */
+
 #ifndef MOUSE_H
 #define MOUSE_H
 
+#ifdef WITH_MOUSE
+
 bool InTextWin(int line,int col);
 bool InScrollBar(int line,int col);
 void MoveToScreenLC(int line,int col);
 void MouseInTextWin(MEVENT &mev);
 void MouseInScrollBar(MEVENT &mev);
 
+extern int UseMouse;
+
+void SetupMouse();
+
+#endif
+
 #endif // MOUSE_H
