@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: options.cc,v 1.23 1999/10/31 12:12:40 lav Exp $ */
+/* $Id: options.cc,v 1.25 2001/07/05 10:18:13 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -202,6 +202,7 @@ const struct init init[]=
    { "backupnum",    NUM,  &MaxBackup		      },
    { "preferpagetop",NUM,  &PreferPageTop	      },
    { "wordwrap",     NUM,  &wordwrap		      },
+   { "usemouse",     NUM,  &UseMouse		      },
    { NULL }
 };
 const struct init term[]=
@@ -288,7 +289,7 @@ void  SaveConfToFile(const char *f,const struct init *init)
 
 void  SaveConf(char *f)
 {
-   Message("Saving the editor options...");
+   MessageSync("Saving the editor options...");
    SaveConfToFile(f,init);
    strcpy(InitName,f);
 }
@@ -296,7 +297,7 @@ void  SaveConf(char *f)
 void  SaveTermOpt()
 {
    char  t[256];
-   Message("Saving the terminal options...");
+   MessageSync("Saving the terminal options...");
 #ifndef MSDOS
    sprintf(t,"%s/.le/term-%s",HOME,TERM);
 #else
