@@ -16,7 +16,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: textpoin.h,v 1.6 1999/10/30 22:26:45 lav Exp $ */
+/* $Id: textpoin.h,v 1.7 2000/09/04 08:19:02 lav Exp $ */
+
+#ifndef TEXTPOINT_H
+#define TEXTPOINT_H
+
+#include <string.h>
 
 #define  COLUNDEFINED      1
 #define  LINEUNDEFINED     2
@@ -26,7 +31,8 @@ class TextPoint
    offs  offset;
    num   line,col;
    int   flags;
-   bool	 cached;
+   static TextPoint cached_array[];
+   static int cached_array_ptr;
 
    TextPoint   *next;
    static TextPoint   *base;
@@ -37,7 +43,9 @@ class TextPoint
    void  FindOffset();
    void  FindLineCol();
 
-   void  Init();
+   void  Init() {
+      offset=line=col=flags=0;
+   }
 
 public:
    offs  Offset()
@@ -75,7 +83,7 @@ public:
    TextPoint(const TextPoint&);
    TextPoint(offs,num,num);
 
-   static void CacheTextPoint(TextPoint *);
+   void CacheTextPoint();
 
    ~TextPoint();
 
@@ -116,3 +124,5 @@ extern TextPoint  TextBegin;
 
 #define ScrPtr  ScreenTop.Offset()
 #define ScrLine ScreenTop.Line()
+
+#endif
